local MAX_GROUPS = 30
local MAX_SPAM_AMOUNT = 10

local channelDefault = {
	true, -- SAY 1
	true, -- WHISPER 2
	true, -- BN WHISPER 3
	true, -- PARTY 4
	true, -- RAID 5
	true, -- GUILD 6
	true, -- OFFICER 7
	true, -- YELL 8
}
CookyChat.defaults = {	
	profile = {
		trigger = {
		},
		reply = {
		},
		groupActive = {
		},
		groupCaseSensitive = {
		},
		groupChannelActive = {
		},
		whitelist = {
		},
		
		exactMode = false,
		semiOnOff = false,
		globalWhitelist = "",
		blacklist = "",
		hideChannels = true,
		globalActive = true,
		caseSensitive = false,
		numFilled = 0,
		spamAmount = 3,
		seperateChannelActivityOption = false,
		icon = {hide = false, radius = 80, minimapPos = 45},
	},
}

local tempTrigger
local tempReply

function CookyChat:CreateNewGroup()
	if tempTrigger == "" or tempTrigger == nil then
		print("|cffBF5FFFCooky|rChat: Missing trigger.")
	end
	if tempReply == "" or tempReply == nil then
		print("|cffBF5FFFCooky|rChat: Missing reply.")
	end
	if CookyChat.db.profile.numFilled == MAX_GROUPS then
		print("|cffBF5FFFCooky|rChat: Maximum number of groups filled.")
	end
	
	if tempTrigger and tempReply and (CookyChat.db.profile.numFilled < MAX_GROUPS) then
		
		table.insert(CookyChat.db.profile.trigger, tempTrigger)
		table.insert(CookyChat.db.profile.reply, tempReply)
		table.insert(CookyChat.db.profile.groupActive, true)
		table.insert(CookyChat.db.profile.groupCaseSensitive, false)
		table.insert(CookyChat.db.profile.groupChannelActive, channelDefault)
		
		CookyChat.db.profile.numFilled = CookyChat.db.profile.numFilled + 1
		tempTrigger = nil
		tempReply = nil
		print("|cffBF5FFFCooky|rChat: New group created.")
	end
end

function CookyChat:DeleteGroup(group)
	table.remove(CookyChat.db.profile.trigger, group)
	table.remove(CookyChat.db.profile.reply, group)
	table.remove(CookyChat.db.profile.groupActive, group)
	table.remove(CookyChat.db.profile.groupCaseSensitive, group)
	table.remove(CookyChat.db.profile.groupChannelActive, group)
	table.remove(CookyChat.db.profile.whitelist, group)
	CookyChat.db.profile.numFilled = CookyChat.db.profile.numFilled - 1
	print("|cffBF5FFFCooky|rChat: Group deleted.")
end

CookyChat.options = {
	name = "CookyChat",
	handler = CookyChat,
	type = "group",
	args = {
	
		groups = {
			name = "Group Settings",
			type = "group",
			order = 1,
			args = {
				semiOffOption = {
					type = "toggle",
					name = "\"Semi-Off\" mode",
					desc = "Characters in the \"Global Whitelist\" will still be replied to in this mode even if the addon is turned off.",
					get = function() return CookyChat.db.profile.semiOnOff end,
					set = function() CookyChat.db.profile.semiOnOff = not CookyChat.db.profile.semiOnOff CookyChat:UpdateDisplay() end,
					order = 1,
				},
				
				exactModeOption = {
					type = "toggle",
					name = "\"Exact\" mode",
					desc = "Triggers are required to be matched exactly, no additional letters or symbols around the word. I.E. \"test\" would trigger but \"1test\" would not.",
					get = function() return CookyChat.db.profile.exactMode end,
					set = function() CookyChat.db.profile.exactMode = not CookyChat.db.profile.exactMode CookyChat:UpdateDisplay() end,
					order = 2,
				},
				
				minimapIcon = {
					type = "toggle",
					name = "Minimap Icon",
					desc = "Turns the minimap icon on or off.",
					get = function() return not CookyChat.db.profile.icon.hide end,
					set = function() 
							CookyChat.db.profile.icon.hide = not CookyChat.db.profile.icon.hide 
							CookyChat:RefreshMMButton()
							end,
					order = 3,
				},
				
				spamAmount = {
					type = "range",
					name = "Maximum spam amount",
					desc = "Maximum amount of messages to send in a 10 second time frame.",
					min = 1,
					max = MAX_SPAM_AMOUNT,
					step = 1,
					get = function() return CookyChat.db.profile.spamAmount end,
					set = function(info, val) CookyChat.db.profile.spamAmount = val end,
					order = 4,
				},
				
				whitelistInput = {
					type = "input",
					name = "Global Whitelist",
					desc = "Insert character names that you want to whitelist, seperated by spaces. Character names in this box will still be replied to in \"Semi-Off\" mode.",
					get = function() return CookyChat.db.profile.globalWhitelist end,
					set = function(info, val) CookyChat.db.profile.globalWhitelist = val end,
					order = 5,
				},
				
				blacklistInput = {
					type = "input",
					name = "Global Blacklist",
					desc = "Insert character names that you want to never reply to, seperated by spaces. Can't blacklist BNet names.",
					get = function() return CookyChat.db.profile.blacklist end,
					set = function(info, val) CookyChat.db.profile.blacklist = val end,
					order = 6,
				},
				
				seperateChannelActive = {
					type = "toggle",
					name = "Per Channel Activity",
					desc = "Allows trigger groups to work on a per channel basis.",
					get = function() return CookyChat.db.profile.seperateChannelActivityOption end,
					set = function(info,val) CookyChat.db.profile.seperateChannelActivityOption = not CookyChat.db.profile.seperateChannelActivityOption end,
					order = 7,
				},
				
				hidePerChannel = {
					type = "toggle",
					desc = "Hide/Show the 'Active Channels' selection. The trigger will still reply on only the selected channels, this merely hides the selection of checkboxes",
					name = "Show the Active Channels",
					order = 8,
					hidden = function() return not CookyChat.db.profile.seperateChannelActivityOption end,
					get = function() return not CookyChat.db.profile.hideChannels end,
					set = function(info, val) CookyChat.db.profile.hideChannels = not CookyChat.db.profile.hideChannels end,
				},
				
				newGroup = {
					type = "group",
					name = "Create new groups",
					inline = true,
					order = 9,
					args = {
						newTrigger = {
							type = "input",
							name = "New group's trigger",
							desc = "The message that will trigger the autoreply.",
							order = 1,
							set = function(info,val) tempTrigger = val end,
							get = function() return tempTrigger end,
						},

						newReply = {
							type = "input",
							name = "New group's reply",
							desc = "The message that will be sent.",
							order = 2,
							set = function(info,val) tempReply = val end,
							get = function() return tempReply end,
						},
						
						applyButton = {
							type = "execute",
							name = "Create your new group",
							order = 3,
							func = function() CookyChat:CreateNewGroup() end,
						},
					},
				},
			},
		},
	},
}

function CookyChat:CreateGroups()
	for i = 1, MAX_GROUPS do
		local group = {
			type = "group",
			inline = true,
			order = 9+i,
			hidden = function() return not (i <= CookyChat.db.profile.numFilled) end,
			name = "Trigger Group "..i,
			args = {
				trigger = {
					type = "input",
					name = "Trigger",
					get = function() return CookyChat.db.profile.trigger[i] end,
					set = function(info, val) CookyChat.db.profile.trigger[i] = val end,
					order = 1,
				},
				
				reply = {
					type = "input",
					name = "Reply",
					get = function() return CookyChat.db.profile.reply[i] end,
					set = function(info, val) CookyChat.db.profile.reply[i] = val end,
					order = 2,
				},
				
				whitelist = {
					type = "input",
					name = "Group Whitelist",
					desc = "Insert character names of specific people you want this group to reply to, sperated by spaces. If empty, will reply to anyone who triggers the group. Will always reply to BNet whispers.",
					get = function() return CookyChat.db.profile.whitelist[i] end,
					set = function(info, val) CookyChat.db.profile.whitelist[i] = val end,
					order = 3,
				},
				
				active = {
					type = "toggle",
					name = "Active",
					desc = "Turns this group on or off.",
					get = function() return CookyChat.db.profile.groupActive[i] end,
					set = function(info, val) CookyChat.db.profile.groupActive[i] = val end,
					order = 4,
				},
				
				caseSensitive = {
					type = "toggle",
					name = "Case Sensitive",
					desc = "Turns case sensitivity on or off for this group",
					get = function() return CookyChat.db.profile.groupCaseSensitive[i] end,
					set = function() CookyChat.db.profile.groupCaseSensitive[i] = not CookyChat.db.profile.groupCaseSensitive[i] end,
					order = 5,
				},
				
				delete = {
					type = "execute",
					name = "Delete this group",
					func = function() CookyChat:DeleteGroup(i) end,
					order = 6,
				},
				
				channelSelectGroup = {
					type = "group",
					name = "Active Channels",
					inline = true,
					desc = "Choose which chat channels the group is active on.",
					hidden = function() 
								if not CookyChat.db.profile.seperateChannelActivityOption or CookyChat.db.profile.hideChannels then
									return true
								end
							end,
					order = 7,
					args = {
						channelSelectGroupSay = {
							type = "toggle",
							name = "Say",
							order = 1,
							get = function() return CookyChat.db.profile.groupChannelActive[i][1] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][1] = not CookyChat.db.profile.groupChannelActive[i][1] end,
						},
						channelSelectGroupWhisper = {
							type = "toggle",
							name = "Whispers",
							order = 2,
							get = function() return CookyChat.db.profile.groupChannelActive[i][2] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][2] = not CookyChat.db.profile.groupChannelActive[i][2] end,
						},
						channelSelectGroupBNWhisper = {
							type = "toggle",
							name = "Battle.Net whispers",
							order = 3,
							get = function() return CookyChat.db.profile.groupChannelActive[i][3] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][3] = not CookyChat.db.profile.groupChannelActive[i][3] end,
						},
						channelSelectGroupParty = {
							type = "toggle",
							name = "Party",
							order = 4,
							get = function() return CookyChat.db.profile.groupChannelActive[i][4] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][4] = not CookyChat.db.profile.groupChannelActive[i][4] end,
						},
						channelSelectGroupRaid = {
							type = "toggle",
							name = "Raid",
							order = 5,
							get = function() return CookyChat.db.profile.groupChannelActive[i][5] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][5] = not CookyChat.db.profile.groupChannelActive[i][5] end,
						},
						channelSelectGroupGuild = {
							type = "toggle",
							name = "Guild",
							order = 6,
							get = function() return CookyChat.db.profile.groupChannelActive[i][6] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][6] = not CookyChat.db.profile.groupChannelActive[i][6] end,
						},
						channelSelectGroupOfficer = {
							type = "toggle",
							name = "Officer",
							order = 7,
							get = function() return CookyChat.db.profile.groupChannelActive[i][7] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][7] = not CookyChat.db.profile.groupChannelActive[i][7] end,
						},
						channelSelectGroupYell = {
							type = "toggle",
							name = "Yell",
							order = 7,
							get = function() return CookyChat.db.profile.groupChannelActive[i][8] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][8] = not CookyChat.db.profile.groupChannelActive[i][8] end,
						},
					},
				},
			},
		}
		
		CookyChat.options.args.groups.args[tostring(i)] = group
	end
end